summary refs log tree commit diff
path: root/pkgs/build-support
diff options
context:
space:
mode:
authorgithub-actions[bot] <41898282+github-actions[bot]@users.noreply.github.com>2023-10-28 12:01:19 +0000
committerGitHub <noreply@github.com>2023-10-28 12:01:19 +0000
commit519b7ea0c3a8e612eaf7e64128e967549615b6a7 (patch)
tree8052537e4fd51b1575e0a8b9bfb26a7c5487e7b5 /pkgs/build-support
parentcb64b504a0a80c4df9e96426d830f94080760628 (diff)
parentb30e97ace2945f9ddcf1b233e04d45ef3c511d9b (diff)
downloadnixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar.gz
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar.bz2
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar.lz
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar.xz
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.tar.zst
nixpkgs-519b7ea0c3a8e612eaf7e64128e967549615b6a7.zip
Merge master into staging-next
Diffstat (limited to 'pkgs/build-support')
-rw-r--r--pkgs/build-support/fetchtorrent/default.nix (renamed from pkgs/build-support/fetchbittorrent/default.nix)4
-rw-r--r--pkgs/build-support/fetchtorrent/tests.nix (renamed from pkgs/build-support/fetchbittorrent/tests.nix)10
2 files changed, 7 insertions, 7 deletions
diff --git a/pkgs/build-support/fetchbittorrent/tests.nix b/pkgs/build-support/fetchtorrent/tests.nix
index fce1b3933a7..b36c82c6326 100644
--- a/pkgs/build-support/fetchbittorrent/tests.nix
+++ b/pkgs/build-support/fetchtorrent/tests.nix
@@ -1,22 +1,22 @@
-{ testers, fetchFromBittorrent, ... }:
+{ testers, fetchtorrent, ... }:
 
 {
-  http-link = testers.invalidateFetcherByDrvHash fetchFromBittorrent {
+  http-link = testers.invalidateFetcherByDrvHash fetchtorrent {
     url = "https://webtorrent.io/torrents/wired-cd.torrent";
     hash = "sha256-OCsC22WuanqoN6lPv5wDT5ZxPcEHDpZ1EgXGvz1SDYo=";
     backend = "transmission";
   };
-  magnet-link = testers.invalidateFetcherByDrvHash fetchFromBittorrent {
+  magnet-link = testers.invalidateFetcherByDrvHash fetchtorrent {
     url = "magnet:?xt=urn:btih:a88fda5954e89178c372716a6a78b8180ed4dad3&dn=The+WIRED+CD+-+Rip.+Sample.+Mash.+Share&tr=udp%3A%2F%2Fexplodie.org%3A6969&tr=udp%3A%2F%2Ftracker.coppersurfer.tk%3A6969&tr=udp%3A%2F%2Ftracker.empire-js.us%3A1337&tr=udp%3A%2F%2Ftracker.leechers-paradise.org%3A6969&tr=udp%3A%2F%2Ftracker.opentrackr.org%3A1337&tr=wss%3A%2F%2Ftracker.btorrent.xyz&tr=wss%3A%2F%2Ftracker.fastcast.nz&tr=wss%3A%2F%2Ftracker.openwebtorrent.com&ws=https%3A%2F%2Fwebtorrent.io%2Ftorrents%2F&xs=https%3A%2F%2Fwebtorrent.io%2Ftorrents%2Fwired-cd.torrent";
     hash = "sha256-OCsC22WuanqoN6lPv5wDT5ZxPcEHDpZ1EgXGvz1SDYo=";
     backend = "transmission";
   };
-  http-link-rqbit = testers.invalidateFetcherByDrvHash fetchFromBittorrent {
+  http-link-rqbit = testers.invalidateFetcherByDrvHash fetchtorrent {
     url = "https://webtorrent.io/torrents/wired-cd.torrent";
     hash = "sha256-OCsC22WuanqoN6lPv5wDT5ZxPcEHDpZ1EgXGvz1SDYo=";
     backend = "rqbit";
   };
-  magnet-link-rqbit = testers.invalidateFetcherByDrvHash fetchFromBittorrent {
+  magnet-link-rqbit = testers.invalidateFetcherByDrvHash fetchtorrent {
     url = "magnet:?xt=urn:btih:a88fda5954e89178c372716a6a78b8180ed4dad3&dn=The+WIRED+CD+-+Rip.+Sample.+Mash.+Share&tr=udp%3A%2F%2Fexplodie.org%3A6969&tr=udp%3A%2F%2Ftracker.coppersurfer.tk%3A6969&tr=udp%3A%2F%2Ftracker.empire-js.us%3A1337&tr=udp%3A%2F%2Ftracker.leechers-paradise.org%3A6969&tr=udp%3A%2F%2Ftracker.opentrackr.org%3A1337&tr=wss%3A%2F%2Ftracker.btorrent.xyz&tr=wss%3A%2F%2Ftracker.fastcast.nz&tr=wss%3A%2F%2Ftracker.openwebtorrent.com&ws=https%3A%2F%2Fwebtorrent.io%2Ftorrents%2F&xs=https%3A%2F%2Fwebtorrent.io%2Ftorrents%2Fwired-cd.torrent";
     hash = "sha256-OCsC22WuanqoN6lPv5wDT5ZxPcEHDpZ1EgXGvz1SDYo=";
     backend = "rqbit";
diff --git a/pkgs/build-support/fetchbittorrent/default.nix b/pkgs/build-support/fetchtorrent/default.nix
index 916c7e7d8c9..beb2415df70 100644
--- a/pkgs/build-support/fetchbittorrent/default.nix
+++ b/pkgs/build-support/fetchtorrent/default.nix
@@ -30,13 +30,13 @@ let
   jsonConfig = (formats.json {}).generate "jsonConfig" config;
 in
 runCommand name {
-  nativeBuildInputs = [ cacert ] ++ (if (backend == "transmission" ) then [ transmission_noSystemd ] else if (backend == "rqbit") then [ rqbit ] else throw "rqbit or transmission are the only available backends for fetchbittorrent");
+  nativeBuildInputs = [ cacert ] ++ (if (backend == "transmission" ) then [ transmission_noSystemd ] else if (backend == "rqbit") then [ rqbit ] else throw "rqbit or transmission are the only available backends for fetchtorrent");
   outputHashAlgo = if hash != "" then null else "sha256";
   outputHash = hash;
   outputHashMode = if recursiveHash then "recursive" else "flat";
 
   # url will be written to the derivation, meaning it can be parsed and utilized
   # by external tools, such as tools that may want to seed fetchBittorrent calls
   # in nixpkgs
   inherit url;
 }
@@ -30,13 +30,13 @@ let
 
   # url will be written to the derivation, meaning it can be parsed and utilized
-  # by external tools, such as tools that may want to seed fetchBittorrent calls
+  # by external tools, such as tools that may want to seed fetchtorrent calls
   # in nixpkgs
   inherit url;